import csv
import pandas as pd


def split_sequences_into_individual_cells(
    input_filepath: str, output_filepath: str
) -> None:
    """Enables visualization of SNPS within DNA sequences in Excel by splitting
    each nucleotide into its own column in a CSV."""
    with open(output_filepath, "w+") as output_file:
        writer = csv.writer(output_file)

        with open(input_filepath, newline="") as input_file:
            csv_reader = csv.reader(input_file, delimiter="\t")
            for row in csv_reader:
                seq_list = list(row[0])
                writer.writerow(seq_list)


def exploratory_data_analysis(seq_file: str) -> None:
    df = pd.read_csv(seq_file)
    print(df.info())
    print(df.head(20).describe())
    print(df.nunique()> 1)
    print(df.columns[df.nunique() > 1])




def main():
    # split_sequences_into_individual_cells(
    #     "/home/user/DNABERT_model/data/raw_seqs.tsv",
    #     "/home/user/DNABERT_model/data/seq_cols.csv",
    # )

    exploratory_data_analysis("/home/user/DNABERT_model/data/seq_cols.csv")


if __name__ == "__main__":
    main()
